glue\_genes.glue\_single\_cell.data.DataAnnDataTranslator
=========================================================

.. currentmodule:: glue_genes.glue_single_cell.data

.. autoclass:: DataAnnDataTranslator

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataAnnDataTranslator.__init__
      ~DataAnnDataTranslator.to_data
      ~DataAnnDataTranslator.to_object
      ~DataAnnDataTranslator.unwrap_components
   
   

   
   
   